==> build-okapi-root-0.21-sources.zip: build-okapi-root-0.21/okapi/steps/languagetool/src/test/java/net/sf/okapi/steps/languagetool/LanguageToolTest.java <==
/*
 * ===========================================================================
 * Copyright (C) 2013 by the Okapi Framework contributors
 * -----------------------------------------------------------------------------
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * See also the full LGPL text here: http://www.gnu.org/copyleft/lesser.html
 * ===========================================================================
 */

package net.sf.okapi.steps.languagetool;

import static org.junit.Assert.assertNotNull;
import net.sf.okapi.common.LocaleId;
import net.sf.okapi.common.annotation.GenericAnnotations;
import net.sf.okapi.common.resource.ITextUnit;
import net.sf.okapi.common.resource.TextFragment;
import net.sf.okapi.common.resource.TextFragment.TagType;
import net.sf.okapi.common.resource.TextUnit;

import org.junit.Before;
import org.junit.Test;

public class LanguageToolTest {

	private LanguageTool lt;

	@Before
	public void setUp () {
		lt = new LanguageTool(null, LocaleId.ENGLISH, LocaleId.FRENCH);
	}

	@Test
	public void simpleTest () {
		ITextUnit tu = new TextUnit("id", "original teext");
		tu.setTargetContent(LocaleId.FRENCH, new TextFragment("texte original"));
		lt.run(tu);
		GenericAnnotations anns = tu.getSource().getAnnotation(GenericAnnotations.class);
		assertNotNull(anns);
		anns = tu.getTarget(LocaleId.FRENCH).getAnnotation(GenericAnnotations.class);
		assertNotNull(anns);
	}

	@Test
	public void testWithCodes () {
		TextFragment tf = new TextFragment();
		tf.append(TagType.OPENING, "b", "<b>");
		tf.append("text");
		tf.append(TagType.CLOSING, "b", "</b>");
		ITextUnit tu = new TextUnit("id");
		tu.setSourceContent(tf);
		tu.setTargetContent(LocaleId.FRENCH, tf.clone());
		lt.run(tu);
		GenericAnnotations anns = tu.getSource().getAnnotation(GenericAnnotations.class);
		assertNotNull(anns);
		anns = tu.getTarget(LocaleId.FRENCH).getAnnotation(GenericAnnotations.class);
		assertNotNull(anns);
	}
	
//	@Test
//	public void testRuleAccess () throws IOException {
//		JLanguageTool jtl = new JLanguageTool(Language.AMERICAN_ENGLISH);
//		List<Rule> list = jtl.getAllRules();
//		for ( Rule rule : list ) {
//			String id = rule.getId();
//			Category cat = rule.getCategory();
//			String catName = cat.getName();
//			System.out.println("id="+id+", catName="+catName);
//		}
//	}

}

==> build-okapi-root-0.22-sources.zip: build-okapi-root-0.22/okapi/steps/languagetool/src/test/java/net/sf/okapi/steps/languagetool/LanguageToolTest.java <==
/*
 * ===========================================================================
 * Copyright (C) 2013 by the Okapi Framework contributors
 * -----------------------------------------------------------------------------
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * See also the full LGPL text here: http://www.gnu.org/copyleft/lesser.html
 * ===========================================================================
 */

package net.sf.okapi.steps.languagetool;

import static org.junit.Assert.*;
import net.sf.okapi.common.LocaleId;
import net.sf.okapi.common.annotation.GenericAnnotation;
import net.sf.okapi.common.annotation.GenericAnnotationType;
import net.sf.okapi.common.annotation.ITSLQIAnnotations;
import net.sf.okapi.common.resource.ITextUnit;
import net.sf.okapi.common.resource.TextFragment;
import net.sf.okapi.common.resource.TextFragment.TagType;
import net.sf.okapi.common.resource.TextUnit;

import org.junit.Before;
import org.junit.Test;

public class LanguageToolTest {

	private LanguageTool lt;

	@Before
	public void setUp () {
		lt = new LanguageTool(null, LocaleId.ENGLISH, LocaleId.FRENCH);
	}

	@Test
	public void simpleTest1 () {
		ITextUnit tu = new TextUnit("id", "original teext");
		tu.setTargetContent(LocaleId.FRENCH, new TextFragment("texte original"));
		lt.run(tu);
		ITSLQIAnnotations anns = tu.getSource().getAnnotation(ITSLQIAnnotations.class);
		assertNotNull(anns);
		assertEquals(2, anns.getAllAnnotations().size());
		anns = tu.getTarget(LocaleId.FRENCH).getAnnotation(ITSLQIAnnotations.class);
		assertNotNull(anns);
		assertEquals(1, anns.getAllAnnotations().size());
	}

	@Test
	public void simpleTest2 () {
		ITextUnit tu = new TextUnit("id", "File not found: %1");
		tu.setTargetContent(LocaleId.FRENCH, new TextFragment("Fichier non trouv\u00e9: %1"));
		lt.run(tu);
		ITSLQIAnnotations anns = tu.getSource().getAnnotation(ITSLQIAnnotations.class);
		assertNull(anns);
		anns = tu.getTarget(LocaleId.FRENCH).getAnnotation(ITSLQIAnnotations.class);
		assertNotNull(anns);
		assertEquals(1, anns.getAllAnnotations().size());
	}

	@Test
	public void testWithCodes () {
		TextFragment tf = new TextFragment();
		tf.append(TagType.OPENING, "b", "<b>");
		tf.append("<#>");
		tf.append(TagType.CLOSING, "b", "</b>");
		ITextUnit tu = new TextUnit("id");
		tu.setSourceContent(tf);
		tu.setTargetContent(LocaleId.FRENCH, tf.clone());
		lt.run(tu);
		ITSLQIAnnotations anns = tu.getSource().getAnnotation(ITSLQIAnnotations.class);
		assertNotNull(anns);
//TODO: fix inline handling		
		GenericAnnotation ann = anns.getAnnotations(GenericAnnotationType.LQI).get(0);
		assertEquals(0, (int)ann.getInteger(GenericAnnotationType.LQI_XSTART));
		assertEquals(3, (int)ann.getInteger(GenericAnnotationType.LQI_XEND));
		
//		anns = tu.getTarget(LocaleId.FRENCH).getAnnotation(ITSLQIAnnotations.class);
//		assertNotNull(anns);
	}
	
//	@Test
//	public void testRuleAccess () throws IOException {
//		JLanguageTool jtl = new JLanguageTool(Language.AMERICAN_ENGLISH);
//		List<Rule> list = jtl.getAllRules();
//		for ( Rule rule : list ) {
//			String id = rule.getId();
//			Category cat = rule.getCategory();
//			String catName = cat.getName();
//			System.out.println("id="+id+", catName="+catName);
//		}
//	}

}
